kombu.compression — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.compression

Object utilities.

copyright: | 2009 - 2011 by Ask Solem.
license: | BSD, see LICENSE for more details.

class `kombu.abstract.` `MaybeChannelBound`(*args, **kwargs)

  Mixin for classes that can be bound to an AMQP channel.

  `bind`(channel)

    Create copy of the instance that is bound to a channel.

  `channel`

    Current channel if the object is bound.

  `is_bound`

    Flag set if the channel is bound.

  `maybe_bind`(channel)

    Bind instance to channel if not already bound.

  `revive`(channel)

    Revive channel afer connection re-established.

    Used by `ensure()`.

  `when_bound`()

    Callback called when the class is bound.

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »